"""
Flask commands
"""
from putio_automator.commands.account import manager as account
from putio_automator.commands.config import manager as config
from putio_automator.commands.db import manager as db
from putio_automator.commands.docker import manager as docker
from putio_automator.commands.files import manager as files
from putio_automator.commands.torrents import manager as torrents
from putio_automator.commands.transfers import manager as transfers
